import json
from requests import post
from .utils import generate_random_string
from .exceptions import Error

class Account:
    headers = {'Content-Type': 'application/json'}
    username: str = None
    prefix: str = None

    def __init__(self,username: str = None,prefix: str = 'mail'):
        if username is None:
            username = generate_random_string()
        elif not username.isalnum():
            raise Error('The username can only be letters and numbers.')
        if not prefix.isalnum():
            raise Error('The prefix can only be letters and numbers.')
        self.username = username
        self.prefix = prefix
        self.address = username+'@'+prefix+'.iemail.eu.org'
        
    def get_message(self, latest=0):
        assert latest >= 0, IndexError('Latest must be >= 0')
        r = post('https://api.iemail.eu.org/',headers=self.headers,data=json.dumps({'username': self.username,'prefix': self.prefix}),timeout=10)
        result = r.json()
        if len(result) <= latest:
            raise IndexError(f'No message found! There are only {len(result)} messages.')
        return result[latest]

    def get_messages(self):
        r = post('https://api.iemail.eu.org/',headers=self.headers,data=json.dumps({'username': self.username,'prefix': self.prefix}),timeout=10)
        return r.json()

if __name__ == '__main__':
    ...


from setuptools import setup
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()
setup(
    name='iemail',
    version='1.0',
    description='Temporary Email Python SDK of https://api.iemail.eu.org/',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url="https://github.com/Danny-Yxzl/mail_gw",
    author="IEmail",
    author_email="i@iemail.eu.org",
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11"
    ],
    keywords="Tempmail mail iemail email API",
    install_requires=["requests"],
    packages=["iemail"],
    project_urls={
        "HomePage": "https://iemail.eu.org/",
        "API Docs": "https://docs.iemail.eu.org/",
    },
)
